@@ -166,7 +166,7 @@
 	      )))
   "Options to pass to the Unix-style shell. 
 Don't put `-c' here, as it is added automatically."
-  :type 'string
+  :type '(choice (const nil) string)
   :group 'viper-ex)
 
 (defcustom viper-glob-function
@@ -1956,8 +1956,13 @@ Please contact your system administrator. "
 		(progn
 		  (while (and (not (eolp))
 			      (re-search-forward pat eol-mark t))
-		    (if (or (not opt-c) (y-or-n-p "Replace? "))
+		    (if (or (not opt-c)
+			    (progn
+			      (viper-put-on-search-overlay (match-beginning 0)
+							   (match-end 0))
+			      (y-or-n-p "Replace? ")))
 			(progn
+			  (viper-hide-search-overlay)
 			  (setq matched-pos (point))
 			  (if (not (stringp repl))
 			      (error "Can't perform Ex substitution: No previous replacement pattern"))
@@ -1968,8 +1973,13 @@ Please contact your system administrator. "
 		  (error
 		   "Can't repeat Ex substitution: No previous regular expression"))
 	      (if (and (re-search-forward pat eol-mark t)
-		       (or (not opt-c) (y-or-n-p "Replace? ")))
+		       (or (not opt-c)
+			   (progn
+			     (viper-put-on-search-overlay (match-beginning 0)
+							  (match-end 0))
+			     (y-or-n-p "Replace? "))))
 		  (progn
+		    (viper-hide-search-overlay)
 		    (setq matched-pos (point))
 		    (if (not (stringp repl))
 			(error "Can't perform Ex substitution: No previous replacement pattern"))
@@ -2080,6 +2090,7 @@ Please contact your system administrator. "
 	      (insert region)
 	      ;; ask user
 	      (viper-maybe-checkout (current-buffer))
+	      (setq selective-display nil)
 	      (save-buffer)
 	      (ex-write-info
 	       file-exists ex-file (point-min) (point-max))
